==> apache-ignite-2.6.0-src.zip: apache-ignite-2.6.0-src/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/datastructures/replicated/GridCacheReplicatedDataStructuresFailoverSelfTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.cache.datastructures.replicated;

import org.apache.ignite.cache.CacheAtomicityMode;
import org.apache.ignite.cache.CacheMode;
import org.apache.ignite.internal.processors.cache.datastructures.GridCacheAbstractDataStructuresFailoverSelfTest;

import static org.apache.ignite.cache.CacheAtomicityMode.TRANSACTIONAL;
import static org.apache.ignite.cache.CacheMode.REPLICATED;

/**
 * Failover tests for cache data structures.
 */
public class GridCacheReplicatedDataStructuresFailoverSelfTest
    extends GridCacheAbstractDataStructuresFailoverSelfTest {
    /** {@inheritDoc} */
    @Override protected CacheMode collectionCacheMode() {
        return REPLICATED;
    }

    /** {@inheritDoc} */
    @Override protected CacheAtomicityMode collectionCacheAtomicityMode() {
        return TRANSACTIONAL;
    }

    /**
     * @throws Exception If failed.
     */
    public void testFairReentrantLockConstantMultipleTopologyChangeNonFailoverSafe() throws Exception {
        fail("https://issues.apache.org/jira/browse/IGNITE-6454");
    }

    /**
     * @throws Exception If failed.
     */
    public void testReentrantLockConstantMultipleTopologyChangeNonFailoverSafe() throws Exception {
        fail("https://issues.apache.org/jira/browse/IGNITE-6454");
    }
}

==> apache-ignite-2.7.6-src.zip: apache-ignite-2.7.6-src/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/datastructures/replicated/GridCacheReplicatedDataStructuresFailoverSelfTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.cache.datastructures.replicated;

import org.apache.ignite.cache.CacheAtomicityMode;
import org.apache.ignite.cache.CacheMode;
import org.apache.ignite.internal.processors.cache.datastructures.GridCacheAbstractDataStructuresFailoverSelfTest;

import static org.apache.ignite.cache.CacheAtomicityMode.TRANSACTIONAL;
import static org.apache.ignite.cache.CacheMode.REPLICATED;

/**
 * Failover tests for cache data structures.
 */
public class GridCacheReplicatedDataStructuresFailoverSelfTest
    extends GridCacheAbstractDataStructuresFailoverSelfTest {
    /** {@inheritDoc} */
    @Override protected CacheMode collectionCacheMode() {
        return REPLICATED;
    }

    /** {@inheritDoc} */
    @Override protected CacheAtomicityMode collectionCacheAtomicityMode() {
        return TRANSACTIONAL;
    }

    /**
     *
     */
    @Override public void testFairReentrantLockConstantMultipleTopologyChangeNonFailoverSafe() {
        fail("https://issues.apache.org/jira/browse/IGNITE-6454");
    }

    /**
     *
     */
    @Override public void testReentrantLockConstantMultipleTopologyChangeNonFailoverSafe() {
        fail("https://issues.apache.org/jira/browse/IGNITE-6454");
    }

    /**
     *
     */
    @Override public void testReentrantLockConstantTopologyChangeNonFailoverSafe() {
        fail("https://issues.apache.org/jira/browse/IGNITE-6454");
    }

    /**
     *
     */
    @Override public void testFairReentrantLockConstantTopologyChangeNonFailoverSafe() {
        fail("https://issues.apache.org/jira/browse/IGNITE-6454");
    }
}
